@@ -1,4 +1,5 @@
 {-# LANGUAGE Rank2Types #-}
+{-# LANGUAGE CPP #-}
 {-# LANGUAGE ExistentialQuantification #-}
 {-# LANGUAGE DeriveDataTypeable #-}
 {-|
@@ -61,7 +62,11 @@ import qualified Network.HTTP.Types as H
 import Data.Text (Text)
 import Data.ByteString.Lazy.Char8 () -- makes it easier to use responseLBS
 import Blaze.ByteString.Builder (fromByteString)
+#if MIN_VERSION_vault(0,3,0)
+import Data.Vault.Lazy (Vault)
+#else
 import Data.Vault (Vault)
+#endif
 import Data.Word (Word64)
 
 -- | Information on the request sent by the client. This abstracts away the
@@ -90,6 +95,11 @@ data Request = Request
   ,  serverPort     :: Int
   ,  requestHeaders :: H.RequestHeaders
   -- | Was this request made over an SSL connection?
+  --
+  -- This value should /not/ be used, and will be removed in future revisions
+  -- of WAI. There is no meaningful way that a backend can indicate whether the
+  -- request is actually over a secure channel, due to issues of reverse
+  -- proxying.
   ,  isSecure       :: Bool
   -- | The client\'s host information.
   ,  remoteHost     :: SockAddr
